# Slot: mixin


this slot or class can only be used as a mixin -- equivalent to abstract

URI: [http://w3id.org/biolink/biolinkml/meta/mixin](slot_uri)
## Domain and Range

[Definition](Definition.md) -><sub>opt</sub> [Boolean](Boolean.md)
## Inheritance

## Children

## Used by

 * [ClassDefinition](ClassDefinition.md)
 * [Definition](Definition.md)
 * [SlotDefinition](SlotDefinition.md)
